/**************************************************************************
** 
** File name   : basic.do
** Date        : April 23, 2003
** Author      : Branislav L. Slantchev (slantchev@ucsd.edu)
** Purpose     : Calculate basic statistics and correlations
** Requires    : 1perwar.dta from prepare.do
** Output      : survival.eps file with empirical duration of wars
**
**************************************************************************/
version 8.0
#delimit ;

drop _all;
set more off;

qui log;
loc logopen = r(status);
if "`logopen'" == "on" {; log close; };

set logtype text;
log using logs/basic.log, replace;
di "$S_DATE $S_TIME";

use 1perwar, clear;

/*
** mean, median duration, by type of outcome
*/
centile months; 
su months;
sort outcome;
by outcome: su months;
di in w "-> outcome=     Defeat";
centile months if outcome==1;
di in w "-> outcome=Concessions";
centile months if outcome==2;
di in w "-> outcome=      Gains";
centile months if outcome==3;
di in w "-> outcome=    Victory";
centile months if outcome==4;

/*
** mean, meadian duration by salience
*/
sort salient;
by salient: su months;
di in w "-> salience=    Not salient";
centile months if salient==0;
di in w "-> salience=Equally salient";
centile months if salient==1;
di in w "-> salience=   More salient";
centile months if salient==2;

/*
** outcome by salience
*/
tab outcome salient;

/*
** mean, meadian duration by uncertainty
*/
su months if parmil <= .25;
centile months if parmil <= .25;
su months if parpop <= .25;
centile months if parpop <= .25;

su months if parmil > .25 & parmil <= .5;
centile months if parmil > .25 & parmil <= .5;
su months if parpop > .25 & parpop <= .5;
centile months if parpop > .25 & parpop <= .5;

su months if parmil > .5 & parmil <= .75;
centile months if parmil > .5 & parmil <= .75;
su months if parpop > .5 & parpop <= .75;
centile months if parpop > .5 & parpop <= .75;

su months if parmil > .75;
centile months if parmil > .75;
su months if parpop > .75;
centile months if parpop > .75;

su par*;
centile par*;

/*
** correlations and VIFs
*/
pwcorr pwpop pwmil rloss, star(.05);
qui reg outcome months pwpop pwmil rloss salient talks nstates demo demoloss, robust;
vif;

/* 
** survival probabilities and histogram 
*/
stset months;
sts gen kms = s;    /* Kaplan Meier survivor function */
sort months;
twoway (histogram months, bin(15) gap(4) fraction yaxis(1))
    (line kms months, clwidth(thick) yaxis(2)), 
    xlabel(0(12)108) xtitle("Duration of War in Months")
    ytitle("Fraction of Wars", axis(1))
    ytitle("Conditional Survival Probability", axis(2))
    legend(label(1 "Wars with given duration") label(2 "Kaplan-Meier survivor function"))
    legend(ring(0) position(2) cols(1));
graph export graphs/survival.eps, replace as(eps) logo(off);

log close;
exit;
